@@ -17,8 +17,8 @@ class PredictionEvidence(Enum):
 class MotifType(Enum):
     """Prediction evidence."""
 
-    REPEAT = 'repeat'
-    GENE = 'gene'
+    REPEAT = "repeat"
+    GENE = "gene"
 
 
 @attr.s(auto_attribs=True, frozen=True, slots=True)
@@ -38,6 +38,7 @@ class Motif:
 @attr.s(auto_attribs=True, frozen=True, slots=True)
 class TemplateSequence:
     """Alignment container."""
+
     accession: str
     start: List[int]
     end: List[int]
@@ -46,6 +47,7 @@ class TemplateSequence:
 @attr.s(auto_attribs=True, frozen=True, slots=True)
 class Alignment:
     """Alignment container."""
+
     name: str
     mge_id: str
     hsp_no: int
@@ -81,7 +83,7 @@ class MgeResult:
     substitutions: int
     allele_seq_length: int
     template_length: int
-    depth: np.array
+    depth: np.ndarray
     e_value: float
     template: TemplateSequence  # template sequence
     reference: List[str]
