@@ -19,11 +19,13 @@ LOG = logging.getLogger(__name__)
 # Errors
 class BlastError(Exception):
     """Generic blast errror."""
+
     pass
 
 
 class BlastDatabaseError(BlastError):
     """Errors related to database."""
+
     pass
 
 
@@ -48,7 +50,7 @@ class BlastHsp:
 
     def __len__(self):
         """Length of HSP."""
-        return  self.subject_end - self.subject_start + 1
+        return self.subject_end - self.subject_start + 1
 
 
 @attr.s(auto_attribs=True, frozen=True, slots=True)
@@ -68,15 +70,15 @@ def database_environment(db_path: str) -> Iterator[None]:
     """Set db_path as blast database environment variable within context.
 
     Restore original BLASTDB environment on exit."""
-    original_db_path = os.environ.get('BLASTDB')
-    os.environ['BLASTDB'] = db_path
-    LOG.info(f'Set BLASTDB environment variable to: {db_path}')
+    original_db_path = os.environ.get("BLASTDB")
+    os.environ["BLASTDB"] = db_path
+    LOG.info(f"Set BLASTDB environment variable to: {db_path}")
     yield
-    LOG.info(f'Resetting BLASTDB environment variable to: {original_db_path}')
+    LOG.info(f"Resetting BLASTDB environment variable to: {original_db_path}")
     if original_db_path is None:
-        del os.environ['BLASTDB']
+        del os.environ["BLASTDB"]
     else:
-        os.environ['BLASTDB'] = original_db_path
+        os.environ["BLASTDB"] = original_db_path
 
 
 def _blast_aln_to_vcf_snp(reference, alternative):
@@ -87,15 +89,15 @@ def _blast_aln_to_vcf_snp(reference, alternative):
 
     def _format_snp():
         """Format current snp event."""
-        if curr_event == 'S':
+        if curr_event == "S":
             reference_snp = reference[idx - 1]
             alternative_snp = alternative[idx - 1]
             pos = idx - insertion_modifier
-        elif curr_event == 'D':
+        elif curr_event == "D":
             reference_snp = reference[last_match_pos:idx]
             alternative_snp = alternative[last_match_pos]
             pos = last_match_pos + 1 - insertion_modifier
-        elif curr_event == 'I':
+        elif curr_event == "I":
             reference_snp = reference[last_match_pos]
             alternative_snp = alternative[last_match_pos:idx]
             pos = last_match_pos + 1 - insertion_modifier
@@ -103,7 +105,7 @@ def _blast_aln_to_vcf_snp(reference, alternative):
             # sanity check
             raise ValueError(curr_event)
 
-        return pos, {'ref': reference_snp, 'alt': alternative_snp}
+        return pos, {"ref": reference_snp, "alt": alternative_snp}
 
     reference = reference.upper()
     alternative = alternative.upper()
@@ -124,18 +126,18 @@ def _blast_aln_to_vcf_snp(reference, alternative):
         alt_nt = alternative[idx]
         # detect insertion, deletion and substitution events
         if ref_nt == alt_nt:
-            event = 'M'
-        elif ref_nt == '-':
-            event = 'I'
+            event = "M"
+        elif ref_nt == "-":
+            event = "I"
             curr_insertion_size += 1
-        elif alt_nt == '-':
-            event = 'D'
+        elif alt_nt == "-":
+            event = "D"
         elif ref_nt != alt_nt:
-            event = 'S'
+            event = "S"
         # report snps based on events
         if curr_event is None:  # first event
             curr_event = event
-            if event != 'M':
+            if event != "M":
                 idx = 1
                 pos, snp = _format_snp()  # record snp
                 snps[pos] = snp
@@ -144,7 +146,7 @@ def _blast_aln_to_vcf_snp(reference, alternative):
                 insertion_modifier += curr_insertion_size
                 curr_insertion_size = 0
         elif event != curr_event:  # if current event changes and is not match
-            if curr_event != 'M':
+            if curr_event != "M":
                 pos, snp = _format_snp()  # record snp
                 snps[pos] = snp
                 # add current insertion size to modifier
@@ -152,7 +154,7 @@ def _blast_aln_to_vcf_snp(reference, alternative):
                 curr_insertion_size = 0
             curr_event = event
         # update postion
-        if curr_event == 'M':
+        if curr_event == "M":
             last_match_pos = idx  # set new match pos
     return snps
 
@@ -166,7 +168,7 @@ def _parse_alignment(qseq, hseq):
     for pos, (alt, ref) in enumerate(zip(qseq, hseq), start=1):
         if alt == ref:
             continue
-        snps[pos] = {'ref': ref, 'alt': alt, 'pos': pos}
+        snps[pos] = {"ref": ref, "alt": alt, "pos": pos}
     return snps
 
 
@@ -187,62 +189,64 @@ def _blast_aln_to_cigar(reference, target):
     for ref, alt in zip(reference, target):
         # identify operation
         if ref == alt:
-            operation = 'M'
-        elif ref == '-':
-            operation = 'I'
-        elif alt == '-':
-            operation = 'D'
+            operation = "M"
+        elif ref == "-":
+            operation = "I"
+        elif alt == "-":
+            operation = "D"
         elif ref != alt:
-            operation = 'M'
+            operation = "M"
         else:
             # sanity check
-            raise ValueError(f'ref: {ref}, alt: {alt}')
+            raise ValueError(f"ref: {ref}, alt: {alt}")
 
         if curr_operation is None:
             curr_operation = operation
         elif operation != curr_operation:
-            cigar.append(f'{curr_operation}{length}')
+            cigar.append(f"{curr_operation}{length}")
             curr_operation = operation
             length = 1
         else:
             length += 1
-    cigar.append(f'{curr_operation}{length}')
-    return ' '.join(cigar)
+    cigar.append(f"{curr_operation}{length}")
+    return " ".join(cigar)
 
 
 def _parse_hits_json(blast_result: Dict[str, Any]) -> Iterator[BlastHit]:
     """Parse hits from blast result in json format."""
-    for query in blast_result['BlastOutput2']:
-        query_name = query['report']['results']['search']['query_title']
-        query_len = query['report']['results']['search']['query_len']
-        for hit in query['report']['results']['search']['hits']:
+    for query in blast_result["BlastOutput2"]:
+        query_name = query["report"]["results"]["search"]["query_title"]
+        query_len = query["report"]["results"]["search"]["query_len"]
+        for hit in query["report"]["results"]["search"]["hits"]:
             hsps = []
-            for hsp in hit['hsps']:
-                q_start, q_end = sorted([hsp['query_from'], hsp['query_to']])
-                s_start, s_end = sorted([hsp['hit_from'], hsp['hit_to']])
+            for hsp in hit["hsps"]:
+                q_start, q_end = sorted([hsp["query_from"], hsp["query_to"]])
+                s_start, s_end = sorted([hsp["hit_from"], hsp["hit_to"]])
                 hsp = BlastHsp(
                     query_start=q_start,
                     query_end=q_end,
                     subject_start=s_start,
                     subject_end=s_end,
-                    e_value=hsp['evalue'],
-                    num_gaps=hsp['gaps'],
-                    identity=hsp['identity'] / hsp['align_len'],
-                    expected=hsp['evalue'],
-                    num_subs=hsp['align_len'] -
-                    (hsp['identity'] + hsp['gaps']),
-                    hit_strand=1 if hsp['hit_strand'] == 'Plus' else -1,
-                    cigar=_blast_aln_to_cigar(hsp['qseq'], hsp['hseq']),
-                    query_seq=hsp['qseq'],
-                    midline=hsp['midline'],
-                    subject_seq=hsp['hseq'])
+                    e_value=hsp["evalue"],
+                    num_gaps=hsp["gaps"],
+                    identity=hsp["identity"] / hsp["align_len"],
+                    expected=hsp["evalue"],
+                    num_subs=hsp["align_len"] - (hsp["identity"] + hsp["gaps"]),
+                    hit_strand=1 if hsp["hit_strand"] == "Plus" else -1,
+                    cigar=_blast_aln_to_cigar(hsp["qseq"], hsp["hseq"]),
+                    query_seq=hsp["qseq"],
+                    midline=hsp["midline"],
+                    subject_seq=hsp["hseq"],
+                )
                 hsps.append(hsp)
-            yield BlastHit(query_name=query_name,
-                           query_len=query_len,
-                           subject_len=hit['len'],
-                           subject_name=hit['description'][0]['title'],
-                           depth=_parse_cov(query_name),
-                           hsps=tuple(hsps))
+            yield BlastHit(
+                query_name=query_name,
+                query_len=query_len,
+                subject_len=hit["len"],
+                subject_name=hit["description"][0]["title"],
+                depth=_parse_cov(query_name),
+                hsps=tuple(hsps),
+            )
 
 
 def _element_length(hsps) -> int:
@@ -250,14 +254,14 @@ def _element_length(hsps) -> int:
 
     Estimated to be from first hsp start to last hsp end pos.
     """
-    elem_start = min(h['query_start'] for h in hsps)
-    elem_end = max(h['query_end'] for h in hsps)
+    elem_start = min(h["query_start"] for h in hsps)
+    elem_end = max(h["query_end"] for h in hsps)
     return elem_end - elem_start + 1
 
 
 def _parse_cov(node: str) -> Optional[float]:
     """Parse kmer coverage of contig from contig header."""
-    match = re.search(r'cov_(\d+(\.\d+)?)', node)
+    match = re.search(r"cov_(\d+(\.\d+)?)", node)
     if match:
         return float(match.group(1))
     return None
@@ -268,74 +272,97 @@ def _get_exec_path(path: str) -> Optional[str]:
     try:
         exec_path = _get_executable_path(path)
     except DependencyError:
-        err_message = f'{path} executable not found in PATH'
+        err_message = f"{path} executable not found in PATH"
         LOG.error(err_message)
-        raise click.UsageError(
-            f'{err_message}, please specify path with --{path}-path')
+        raise click.UsageError(f"{err_message}, please specify path with --{path}-path")
     return exec_path
 
 
 def _validate_blast_json(path: str) -> bool:
     """Validate the integrity of a cached blast result file."""
-    LOG.debug('Validate blast json')
+    LOG.debug("Validate blast json")
     try:
         with open(path) as jsfile:
             js = json.load(jsfile)
     except json.decoder.JSONDecodeError:
-        LOG.warning('JSON file is invalid')
+        LOG.warning("JSON file is invalid")
         return False
     # verify its content
-    if 'BlastOutput2' not in js:
+    if "BlastOutput2" not in js:
         return False
     return True
 
 
 def make_database(db: MGEdb, makedb_exec, path=None) -> None:
     """Make blast database from MGEdb in path specifed in BLASTDB env variable."""
-    db_dir = pathlib.Path(os.environ.get('BLASTDB'))  # type: ignore
+    db_dir = pathlib.Path(os.environ.get("BLASTDB"))  # type: ignore
     # set input path
     seq_file = db.record_sequences_path if path is None else path
-    db_name = seq_file.name[:-len(seq_file.suffix)]
+    db_name = seq_file.name[: -len(seq_file.suffix)]
     # full path to database
     blast_db_path = db_dir.joinpath(db_name)
 
     # Get makeblastdb path
     exec_path = _get_exec_path(makedb_exec)
 
-    LOG.info(f'make blast database, path: {blast_db_path}')
-    run_shell(exec_path, '-in', seq_file, '-dbtype',
-              'nucl', '-title', db_name, '-out', blast_db_path)
+    LOG.info(f"make blast database, path: {blast_db_path}")
+    run_shell(
+        exec_path,
+        "-in",
+        seq_file,
+        "-dbtype",
+        "nucl",
+        "-title",
+        db_name,
+        "-out",
+        blast_db_path,
+    )
 
 
 def run_blast(ctx: ExecutionContext, db_name: str, contigs: str) -> str:
     """Search contigs for moitfs in database with blastn."""
     # check if blast results already exists
-    blast_result_path: str = ctx.file_path('blast', '%s_blast.json' % db_name)
+    blast_result_path: str = ctx.file_path("blast", "%s_blast.json" % db_name)
     if os.path.isfile(blast_result_path):
         if _validate_blast_json(blast_result_path):
-            LOG.info(f'using cached blast result: {blast_result_path}')
+            LOG.info(f"using cached blast result: {blast_result_path}")
             return blast_result_path
         else:
-            LOG.warning(f'Cached blast results are invalid, reanalyze files')
+            LOG.warning(f"Cached blast results are invalid, reanalyze files")
 
     # Get BLAST path
     blast_path = _get_exec_path(ctx.blastn_path)
 
     # TODO check filtering of low complexity regions and number of hits thresholds
-    LOG.info(f'running blastn, db: {db_name}')
+    LOG.info(f"running blastn, db: {db_name}")
     try:
-        run_shell(blast_path, '-query', contigs, '-out', blast_result_path,
-                  '-db', db_name, '-num_threads', ctx.num_threads,
-                  '-word_size', ctx.cnf_get_default('getint', 'blast', 'word_size'), '-soft_masking',
-                  ctx.cnf_get_default('getboolean', 'blast', 'soft_masking'), '-task',
-                  ctx.cnf_get_default('get', 'blast', 'task'), '-outfmt', 15)
+        run_shell(
+            blast_path,
+            "-query",
+            contigs,
+            "-out",
+            blast_result_path,
+            "-db",
+            db_name,
+            "-num_threads",
+            ctx.num_threads,
+            "-word_size",
+            ctx.cnf_get_default("getint", "blast", "word_size"),
+            "-soft_masking",
+            ctx.cnf_get_default("getboolean", "blast", "soft_masking"),
+            "-task",
+            ctx.cnf_get_default("get", "blast", "task"),
+            "-outfmt",
+            15,
+        )
     except ExitCodeError as error:
         if os.path.getsize(blast_result_path) == 0:
             os.remove(blast_result_path)
-        if 'database error' in error.stderr.lower():
+        if "database error" in error.stderr.lower():
             raise BlastDatabaseError
         raise click.UsageError(
-            f'Error running blastn; {error.stderr}; cmd: {error.cmd}')
+            f"Error running blastn; {error.stderr}; cmd: {error.cmd}"
+        )
     ctx.check_path(blast_result_path)  # verify that files has been generated
     return blast_result_path
 
@@ -352,5 +379,7 @@ def iter_blast_hits(blast_result_path: str) -> Iterator[BlastHit]:
 def blastdb_exist(ctx: ExecutionContext, db_name: str) -> bool:
     """Check if blastdb with db_name exists."""
     db_path = pathlib.Path(ctx.idx_db_path)
-    return all(db_path.joinpath('{db_name}.{suffix}').is_file()
-               for suffix in ['nin', 'nhr', 'nsq'])
+    return all(
+        db_path.joinpath("{db_name}.{suffix}").is_file()
+        for suffix in ["nin", "nhr", "nsq"]
+    )
