@@ -9,9 +9,8 @@ def run_nhmmscan(ctx: ExecutionContext, db_name, sequence):
 
     # TODO: remove typging ignore
     nhmmscan_path = _get_executable_path(ctx.hmmer_path)  # type: ignore
-    hmm_model = ''
+    hmm_model = ""
 
-    result_tbl = ctx.path('annotate', 'nhmmscan.tsv')    # type: ignore
-    result = run_shell(nhmmscan_path, '--tblout', result_tbl, hmm_model,
-                       sequence)
+    result_tbl = ctx.path("annotate", "nhmmscan.tsv")  # type: ignore
+    result = run_shell(nhmmscan_path, "--tblout", result_tbl, hmm_model, sequence)
     return result
